@@ -159,8 +159,10 @@ void *_ykusb_open_device(int vendor_id, int product_id)
 			    && dev->descriptor.idProduct == YUBIKEY_PID) {
 				rc = YK_EUSBERR;
 				h = usb_open(dev);
+#ifdef LIBUSB_HAS_DETACH_KERNEL_DRIVER_NP
 				if (h != NULL)
 					usb_detach_kernel_driver_np(h, 0);
+#endif
 				goto done;
 			}
 	}
